@@ -2,6 +2,9 @@ import os
 
 import attr
 
+from fixtup.logger import get_logger
+
+logger = get_logger()
 
 @attr.s
 class FixtureTemplate():
@@ -9,16 +12,10 @@ class FixtureTemplate():
     directory: str = attr.ib()
 
     """
-    This flag activate the keep_mounted policy. The fixture is mounted only once at the first test
-    that use this fixture, then reused by each test.
-    """
-    keep_mounted: bool = attr.ib()
-
-    """
-    This flag activate the keep_running policy. The fiture keep running between each test. If you are
+    This flag activate the keep_up policy. The fiture keep running between each test. If you are
     using a container, it doesn't stop between 2 tests. The fixture is stop and unmount when the test process stop.
     """
-    keep_running: bool = attr.ib()
+    keep_up: bool = attr.ib()
 
     """
     This flag control if a fixture is mount in temporary directory or if it's mounted in place in the fixture template
@@ -35,19 +32,27 @@ class FixtureTemplate():
         directory = os.path.join(fixture_repository, identifier)
         return FixtureTemplate(identifier=identifier,
                                directory=directory,
-                               keep_mounted=False,
-                               keep_running=False)
+                               keep_up=False)
 
     @classmethod
     def create_from_fixture_template(cls, path: str, fixture_yml: dict) -> 'FixtureTemplate':
-        keep_mounted = fixture_yml.get('keep_mounted', False)
-        keep_running = fixture_yml.get('keep_running', False)
+        if "keep_up" in fixture_yml:
+            keep_up = fixture_yml['keep_up']
+        # manage keep_running alias in fixtup.yml, set as deprecated
+        # we can drop the support in next version
+        elif "keep_up" not in fixture_yml and "keep_running" in fixture_yml:
+            logger.warning(f"replace keep_running: xxxxxx by keep_up: xxxxxx in {path}/fixtup.yml, the support for keep_running may be dropped")
+            keep_up = fixture_yml['keep_running']
+        else:
+            keep_up = False
+
+
+
         mount_in_place = fixture_yml.get('mount_in_place', False)
         identifier = os.path.basename(path)
         return FixtureTemplate(identifier, path,
                                config=fixture_yml,
-                               keep_mounted=keep_mounted,
-                               keep_running=keep_running,
+                               keep_up=keep_up,
                                mount_in_place=mount_in_place)
 
     @classmethod
@@ -61,8 +66,7 @@ class FixtureTemplate():
         return FixtureTemplate(
             identifier=identifier,
             directory=os.path.join(directory, identifier),
-            keep_mounted=kwargs.get('keep_mounted', False),
-            keep_running=kwargs.get('keep_running', False),
+            keep_up=kwargs.get('keep_up', False),
             mount_in_place=kwargs.get('mount_in_place', False),
         )
 
