@@ -22,7 +22,7 @@ def on_new_fixture(template: FixtureTemplate):
         shutil.copy(os.path.join(RESOURCE_DIR, 'docker', 'docker-compose.yml'), os.path.join(template.directory, 'docker-compose.yml'))
 
 
-def on_mounting(fixture: Fixture):
+def on_starting(fixture: Fixture):
     if _is_docker_compose_absent(fixture):
         return
 
@@ -32,11 +32,6 @@ def on_mounting(fixture: Fixture):
     if exit_code != 0:
         raise OSError(stderr)
 
-
-def on_starting(fixture: Fixture):
-    if _is_docker_compose_absent(fixture):
-        return
-
     docker_compose = plumbum.local['docker-compose']
     cmd = docker_compose['up', '--detach']
     cmd()
@@ -57,15 +52,12 @@ def on_stopping(fixture: Fixture):
         cmd = docker_compose['logs', '--timestamps']
         cmd & plumbum.FG
 
-
-def on_unmounting(fixture: Fixture):
-    if _is_docker_compose_absent(fixture):
-        return
-
     docker_compose = plumbum.local['docker-compose']
     cmd = docker_compose['down']
     cmd()
 
 
+
+
 def _is_docker_compose_absent(fixture: Fixture):
     return not os.path.isfile(os.path.join(fixture.directory, 'docker-compose.yml'))
