@@ -11,12 +11,6 @@ def on_new_fixture(template: FixtureTemplate):
         file.write('')
 
 
-def on_mounting(fixture: Fixture):
-    directory = fixture.directory
-    with io.open(os.path.join(directory, 'mounting.txt'), 'w') as file:
-        file.write('')
-
-
 def on_setup_data(fixture: Fixture):
     directory = os.getcwd()
     with io.open(os.path.join(directory, 'setup_data.txt'), 'w') as file:
@@ -40,7 +34,3 @@ def on_teardown_data(fixture: Fixture):
     with io.open(os.path.join(directory, 'teardown_data.txt'), 'w') as file:
         file.write('')
 
-def on_unmounting(fixture: Fixture):
-    directory = os.getcwd()
-    with io.open(os.path.join(directory, 'unmounting.txt'), 'w') as file:
-        file.write('')
